@@ -4,8 +4,10 @@
 # Modules
 import argparse
 import re
+from getpass import getpass
 
 
+# Functions
 def parse_args(msg):
     parser = argparse.ArgumentParser()
     parser.add_argument(
@@ -17,7 +19,7 @@ def parse_args(msg):
     parser.add_argument(
         "-u", "--user",
         type=str,
-        required=False,
+        required=True,
         help="Username to use when connecting",
         dest="username"
     )
@@ -55,9 +57,9 @@ def parse_args(msg):
         required=False,
         choices=[
             "capabilities", "get", "set-update", "set-replace", "set-delete",
-            "subscribe-stream", "subscribe-poll", "subscribe-once"
+            "subscribe-stream", "subscribe-poll", "subscribe-once", "subscribe2"
         ],
-        default="get",
+        default="capabilities",
         help="gNMI Request type",
     )
     parser.add_argument(
@@ -108,4 +110,7 @@ def parse_args(msg):
         if len(args.gnmi_path) > 1:
             parser.error(f"Only one path supported when doing a {args.operation} operation")
 
+    if not args.password:
+        args.password = getpass("Device password: ")
+
     return args
